@@ -5,6 +5,8 @@ from .data_source import nations,shiptypes,levels
 from .utils import match_keywords
 from nonebot import get_driver
 from nonebot.log import logger
+from httpx import ConnectTimeout
+from asyncio.exceptions import TimeoutError
 
 headers = {
     'Authorization': get_driver().config.api_token
@@ -47,7 +49,7 @@ async def get_ship_name(infolist:List):
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=10)
-            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
+            logger.info(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
         if result['data']:
             for ship in result['data']:
@@ -55,8 +57,8 @@ async def get_ship_name(infolist:List):
         else:
             msg = '没有符合的船只'
         return msg
-    except httpx.ReadTimeout:
-        return '请求超时了，请过会儿再尝试哦~'
+    except (TimeoutError, ConnectTimeout):
+        logger.warning(traceback.format_exc())
     except Exception:
         logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
@@ -73,7 +75,7 @@ async def get_ship_byName(shipname:str):
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=10)
-            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
+            logger.info(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
         List = []
         if result['code'] == 200 and result['data']:
@@ -82,6 +84,8 @@ async def get_ship_byName(shipname:str):
             return List
         else:
             return None
+    except (TimeoutError, ConnectTimeout):
+        logger.warning(traceback.format_exc())
     except Exception:
         logger.error(traceback.format_exc())
         return None
@@ -96,7 +100,7 @@ async def get_AccountIdByName(server:str,name:str):
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=20)
-            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
+            logger.info(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['data']:
             return result['data']['accountId']
@@ -104,7 +108,8 @@ async def get_AccountIdByName(server:str,name:str):
             return 404
         else:
             return None
-    except httpx.ReadTimeout:
+    except (TimeoutError, ConnectTimeout):
+        logger.warning(traceback.format_exc())
         return None
     except Exception:
         logger.error(traceback.format_exc())
