@@ -11,6 +11,8 @@ from .publicAPI import get_AccountIdByName
 from nonebot_plugin_htmlrender import html_to_pic
 from nonebot import get_driver
 from nonebot.log import logger
+from httpx import ConnectTimeout
+from asyncio.exceptions import TimeoutError
 
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
@@ -67,8 +69,9 @@ async def get_AccountInfo(qqid,info):
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=20)
-            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
+            logger.info(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
+            logger.info(f"本次请求服务器计算时间:{result['queryTime']}")
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-info.html")
             template_data = await set_infoparams(result['data'])
@@ -76,13 +79,14 @@ async def get_AccountInfo(qqid,info):
             return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 1000})
         elif result['code'] == 403:
             return f"{result['message']}\n请先绑定账号"
-        elif result['code'] == 404:
+        elif result['code'] == 404 or result['code'] == 405:
             return f"{result['message']}"
         elif result['code'] == 500:
             return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
-            return '查询不到对应信息哦~可能是游戏昵称不正确或QQ未绑定'
-    except httpx.ReadTimeout:
+            return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻'
+    except (TimeoutError, ConnectTimeout):
+        logger.warning(traceback.format_exc())
         return '请求超时了，请过会儿再尝试哦~'
     except Exception:
         logger.error(traceback.format_exc())
